@@ -385,10 +385,10 @@ class TestStoreBoolAction(BaseArgparseOptions):
 
 class ParseStdinTest(BaseArgparseOptions):
 
-    def setup_method(self, method, allow_stdin):
+    def setup_method(self, method):
         super().setup_method(method)
         self.parser.add_argument(
-            "testing", nargs='+', allow_stdin=allow_stdin, action=arghparse.ParseStdin)
+            "testing", nargs='+', action=arghparse.ParseStdin)
 
     def test_none_invalid(self):
         with pytest.raises(argparse_helpers.Error):
@@ -402,22 +402,6 @@ class ParseStdinTest(BaseArgparseOptions):
         namespace = self.parser.parse_args(['foo', 'bar'])
         assert namespace.testing == ['foo', 'bar']
 
-    def test_stdin(self):
-        namespace = self.parser.parse_args(['-'])
-        assert namespace.testing == ['-']
-
-
-class TestParseStdinDisabled(ParseStdinTest):
-
-    def setup_method(self, method):
-        super().setup_method(method, allow_stdin=False)
-
-
-class TestParseStdinEnabled(ParseStdinTest):
-
-    def setup_method(self, method):
-        super().setup_method(method, allow_stdin=True)
-
     def test_stdin(self):
         # stdin is an interactive tty
         with mock.patch('sys.stdin.isatty', return_value=True):
@@ -435,7 +419,7 @@ class TestParseStdinEnabled(ParseStdinTest):
                 (['foo '], ['foo']),
                 (['foo\n'], ['foo']),
                 (['foo', 'bar', 'baz'], ['foo', 'bar', 'baz']),
-                (['\nfoo\n', ' bar ', '\nbaz'], ['foo', 'bar', 'baz']),
+                (['\nfoo\n', ' bar ', '\nbaz'], ['\nfoo', ' bar', '\nbaz']),
         ):
             with mock.patch('sys.stdin') as stdin, \
                     mock.patch("builtins.open", mock.mock_open()) as mock_file:
@@ -555,8 +539,8 @@ class TestExistentPathType(BaseArgparseOptions):
 
     def test_os_errors(self, tmpdir):
         # random OS/FS issues raise errors
-        with mock.patch('snakeoil.osutils.abspath') as abspath:
-            abspath.side_effect = OSError(19, 'Random OS error')
+        with mock.patch('os.path.realpath') as realpath:
+            realpath.side_effect = OSError(19, 'Random OS error')
             with pytest.raises(argparse_helpers.Error):
                 self.parser.parse_args(['--path=%s' % tmpdir])
 
@@ -578,8 +562,8 @@ class TestExistentDirType(BaseArgparseOptions):
 
     def test_os_errors(self, tmp_path):
         # random OS/FS issues raise errors
-        with mock.patch('snakeoil.osutils.abspath') as abspath:
-            abspath.side_effect = OSError(19, 'Random OS error')
+        with mock.patch('os.path.realpath') as realpath:
+            realpath.side_effect = OSError(19, 'Random OS error')
             with pytest.raises(argparse_helpers.Error):
                 self.parser.parse_args([f'--path={tmp_path}'])
 
